Skip to main content Crate seismic_enclave Copy item path Source pub use client ::*;pub use crypto ::*;pub use errors ::*;pub use request_types ::*;client This module provides a client for interacting with a TEE Service server. constants Constants related to the API and the underlying curve. crypto ecdh Support for shared secret computations. ecdsa Structs and functionality related to the ECDSA signature algorithm. ellswift This module provides an implementation of ElligatorSwift as well as a
version of x-only ECDH using it (including compatibility with BIP324). errors ffi secp256k1-sys FFI bindings rand Utilities for random number generation request_types scalar Provides Scalar and related types. schnorr Support for schnorr signatures. serde Serde impl_array_newtype Implement methods and traits for types that contain an inner array. AllPreallocated Represents the set of all capabilities (preallocated memory). InvalidParityValue Error returned when conversion from an integer to Parity fails. Keypair Opaque data structure that holds a keypair consisting of a secret and a public key. Message A (hashed) message input to an ECDSA signature. PublicKey Public key - used to verify ECDSA signatures and to do Taproot tweaks. Scalar Positive 256-bit integer guaranteed to be less than the secp256k1 curve order. Secp256k1 The secp256k1 engine, used to execute all signature operations. SecretKey Secret key - a 256-bit key used to create ECDSA and Taproot signatures. SignOnlyPreallocated Represents the set of capabilities needed for signing (preallocated memory). VerifyOnlyPreallocated Represents the set of capabilities needed for verification (preallocated memory). XOnlyPublicKey An x-only public key, used for verification of Taproot signatures and serialized according to BIP-340. All Represents the set of all capabilities. Error The main error type for this library. Parity Represents the parity passed between FFI function calls. SignOnly Represents the set of capabilities needed for signing. VerifyOnly Represents the set of capabilities needed for verification. Context A trait for all kinds of contexts that lets you define the exact flags and a function to
deallocate memory. It isn’t possible to implement this for types outside this crate. PreallocatedContext Trait marking that a particular context object internally points to
memory that must outlive 'a Signing Marker trait for indicating that an instance of Secp256k1 can be used for signing. ThirtyTwoByteHash Deprecated Trait describing something that promises to be a 32-byte random number; in particular,
it has negligible probability of being zero or overflowing the group order. Such objects
may be converted to Messages without any error paths. Verification Marker trait for indicating that an instance of Secp256k1 can be used for verification.